==> manaplus_1.3.4.14.orig.tar.xz: manaplus-1.3.4.14/src/test/testlauncher.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEST_TESTLAUNCHER_H
#define TEST_TESTLAUNCHER_H

#include "main.h"

#ifdef USE_OPENGL

#include <fstream>
#include <string>
#include <sys/time.h>

#include "localconsts.h"

class TestLauncher
{
    public:
        TestLauncher(std::string test);

        A_DELETE_COPY(TestLauncher)

        ~TestLauncher();

        int exec();

        int calcFps(const timeval *const start, const timeval *const end,
                    const int calls) const;

        int testBackend() const;

        int testSound() const;

        int testRescale() const;

        int testFps();

        int testInternal();

        int testVideoDetection();

        int testBatches();

    private:
        std::string mTest;

        std::ofstream file;
};

#endif
#endif // TEST_TESTLAUNCHER_H

==> manaplus_1.3.7.21.orig.tar.xz: manaplus-1.3.7.21/src/test/testlauncher.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEST_TESTLAUNCHER_H
#define TEST_TESTLAUNCHER_H

#include "main.h"

#ifdef USE_OPENGL

#include <fstream>
#include <string>
#include <sys/time.h>

#include "localconsts.h"

class TestLauncher
{
    public:
        explicit TestLauncher(std::string test);

        A_DELETE_COPY(TestLauncher)

        ~TestLauncher();

        int exec();

        int calcFps(const timeval *const start, const timeval *const end,
                    const int calls) const;

        int testBackend() const;

        int testSound() const;

        int testRescale() const;

        int testFps();

        int testInternal();

        int testVideoDetection();

        int testBatches();

    private:
        std::string mTest;

        std::ofstream file;
};

#endif
#endif  // TEST_TESTLAUNCHER_H
